# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import Literal

from .._models import BaseModel

__all__ = ["ConverseResponse", "Content"]


class Content(BaseModel):
    text: str


class ConverseResponse(BaseModel):
    agent_id: str
    """The ID of the agent used for the converse."""

    content: List[Content]
    """Contents of the converse response."""

    conversation_id: str
    """The ID of the agent conversation."""

    object: Literal["conversation.message"]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .knowledge import Knowledge as Knowledge
from .converse_response import ConverseResponse as ConverseResponse
from .knowledge_list_params import KnowledgeListParams as KnowledgeListParams
from .client_converse_params import ClientConverseParams as ClientConverseParams
from .knowledge_create_params import KnowledgeCreateParams as KnowledgeCreateParams
from .knowledge_update_params import KnowledgeUpdateParams as KnowledgeUpdateParams
from .knowledge_update_response import KnowledgeUpdateResponse as KnowledgeUpdateResponse
